@@ -15,9 +15,6 @@ from mercurial import ui, hg
 
 ROOT = pathlib.Path(__file__).parent
 
-with open(ROOT / "templates" / "changelog.md") as fobj:
-    CHANGE_LOG_TEMPLATE = Template(fobj.read())
-
 
 class ChangeType(Enum):
     chore = "chore"
@@ -52,6 +49,7 @@ class Change:
     RE_PARSE_ISSUE = re.compile(
         r"\b((?:clos(?:e[sd]?|ing)|"
         r"\bfix(?:e[sd]|ing)?|"
+        r"\brelat(?:e[sd]|ing)?|"
         r"\bresolv(?:e[sd]?|ing)|"
         r"\bimplement(?:s|ed|ing)?)(:?))"
         r"(?P<issue>.+)",
@@ -125,13 +123,18 @@ class Changelog:
     def _change_from_commit(self, commit):
         return Change.from_commit(commit)
 
-    def render(self):
-        return CHANGE_LOG_TEMPLATE.render(
-            changelog=self, ChangeType=ChangeType, date=date
+    def render(self, format="md"):
+        with open(ROOT / "templates" / f"changelog.{format}") as fobj:
+            change_log_template = Template(fobj.read())
+
+        return change_log_template.render(
+            changelog=self, ChangeType=ChangeType, date=date, len=len
         )
 
 
-def generate_changelog(version, revset="last(ancestors(.) and tag())::.", repopath="."):
+def generate_changelog(
+    version, revset="last(ancestors(.) and tag())::.", repopath=".", format="md"
+):
     changelog = Changelog(version)
     repo = hg.repository(ui.ui(), repopath.encode("utf-8"))
 
@@ -143,4 +146,4 @@ def generate_changelog(version, revset="last(ancestors(.) and tag())::.", repopa
 
         changelog.add_commit(commit)
 
-    return changelog.render()
+    return changelog.render(format=format)
