@@ -276,7 +276,9 @@ def do_release(release_type, no_previous_tag_check, dry_run):
                 )
 
     changelog_content = (
-        generate_changelog(new_version, format=changelog_format).rstrip()
+        generate_changelog(
+            new_version, format=changelog_format, revset=f"{current_version}::."
+        ).rstrip()
         + "\n\n"
         + previous_content.lstrip()
     ).strip()
